/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

/**
 * nsIGfxInfo2 is a separately implemented extension of nsIGfxInfo, to
 * allow us (in effect) to tack things onto the nsIGfxInfo interface
 * without changing it.
 */

[scriptable, uuid(9C8D8F44-6D52-45AA-8921-734EF4DF5DFE)]
interface nsIGfxInfo2 : nsISupports
{
  /**
   * Not really Gfx-related.  Here for convenience,
   * possibly only temporarily.  See bug 1102295.
   */
  readonly attribute DOMString countryCode;
};

